require 'spec_helper'

class LoginValidator < Assent::Validator
  field :name, presence: true
end

describe Assent::Validator do
  let(:validator) { LoginValidator.new }

  describe '.validate' do
    it 'validates the input against the rules and returns true when valid' do
      input = Hash.new
      input[:name] = 'Frank'
      expect(validator.validate(input)).to eq(true)
    end

    it 'returns false when the input is not valid' do
      input = Hash.new
      expect(validator.validate(input)).to eq(false)
    end

    it 'fills the errors when the input is not valid' do
      input = Hash.new
      validator.validate(input)
      expect(validator.errors).not_to be_empty
      expect(validator.errors).to eq({:name => ["The name is required."]})
    end
  end
end

describe Assent::Validate do
  let(:error) { Assent::Errors.new { include Assent::Config }}
  let(:validator) { Assent::Validate }

  describe '.required' do

    it 'checks if a field is not blank' do
      validation = validator.new(:name, "Frank", {:presence=>true}, error)
      expect(validation.send(:required)).to eq(true)
    end

    it "adds an error when a field is required and empty" do
      validation = validator.new(:name, nil, {:presence=>true}, error)
      validation.send(:required)
      expect(error.errors).to eq({:name => ["The name is required."]})
    end
  end

  describe '.accepted' do
    it 'checks if a field is accepted' do
      validation = validator.new(:terms, true, {:accepted=>true}, error)
      expect(validation.send(:accepted)).to eq(true)
    end

    it 'returns false when a field is not accepted' do
      validation = validator.new(:terms, false, {:accepted=>true}, error)
      expect(validation.send(:accepted)).to eq(false)
    end

    it 'adds an error when a field is not accepted' do
      validation = validator.new(:terms, false, {:accepted=>true}, error)
      validation.send(:accepted)
      expect(error.errors).to eq({:terms => ["The terms is not accepted."]})
    end
  end

  describe '.date' do
    it 'checks if a field is a valid date' do
      validation = validator.new(:date, '20-11-1992', {:date=>true}, error)
      expect(validation.send(:date)).to eq(true)
    end

    it 'returns false when a field is not a valid date' do
      validation = validator.new(:date, '200-11-1992', {:date=>true}, error)
      expect(validation.send(:date)).to eq(false)
      validation2 = validator.new(:date, nil, {:date=>true}, error)
      expect(validation2.send(:date)).to eq(false)
      validation3 = validator.new(:date, "", {:date=>true}, error)
      expect(validation3.send(:date)).to eq(false)
    end

    it 'adds an error when a field is not a date' do
      validation = validator.new(:date, '200-11-1992', {:date=>true}, error)
      validation.send(:date)
      expect(error.errors).to eq({:date=> ["The date is not a valid date."]})
    end
  end

  describe '.ip' do
    it 'checks if a field is a valid ip' do
      validation = validator.new(:ip, '192.168.1.1', {:ip=>true}, error)
      expect(validation.send(:ip)).to eq(true)
    end

    it 'returns false when a field is not a valid ip' do
      validation = validator.new(:ip, '912.456.123.123', {:ip=>true}, error)
      expect(validation.send(:ip)).to eq(false)
    end

    it 'adds an error when a field is not a valid ip' do
      validation = validator.new(:ip, '912.456.123.123', {:ip=>true}, error)
      validation.send(:ip)
      expect(error.errors).to eq({:ip => ["The ip is not a valid ip."]})
    end
  end
end
